# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from moneyforward_acplus.configuration import Configuration


class SubAccount(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'sub_account_name': 'str',
        'tax': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'sub_account_name': 'subAccountName',
        'tax': 'tax'
    }

    def __init__(self, account_id=None, sub_account_name=None, tax=None, local_vars_configuration=None):  # noqa: E501
        """SubAccount - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._sub_account_name = None
        self._tax = None
        self.discriminator = None

        self.account_id = account_id
        self.sub_account_name = sub_account_name
        self.tax = tax

    @property
    def account_id(self):
        """Gets the account_id of this SubAccount.  # noqa: E501

        勘定科目ID  # noqa: E501

        :return: The account_id of this SubAccount.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this SubAccount.

        勘定科目ID  # noqa: E501

        :param account_id: The account_id of this SubAccount.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def sub_account_name(self):
        """Gets the sub_account_name of this SubAccount.  # noqa: E501

        補助科目名  # noqa: E501

        :return: The sub_account_name of this SubAccount.  # noqa: E501
        :rtype: str
        """
        return self._sub_account_name

    @sub_account_name.setter
    def sub_account_name(self, sub_account_name):
        """Sets the sub_account_name of this SubAccount.

        補助科目名  # noqa: E501

        :param sub_account_name: The sub_account_name of this SubAccount.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sub_account_name is None:  # noqa: E501
            raise ValueError("Invalid value for `sub_account_name`, must not be `None`")  # noqa: E501

        self._sub_account_name = sub_account_name

    @property
    def tax(self):
        """Gets the tax of this SubAccount.  # noqa: E501

        税区分  # noqa: E501

        :return: The tax of this SubAccount.  # noqa: E501
        :rtype: str
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this SubAccount.

        税区分  # noqa: E501

        :param tax: The tax of this SubAccount.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tax is None:  # noqa: E501
            raise ValueError("Invalid value for `tax`, must not be `None`")  # noqa: E501

        self._tax = tax

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from moneyforward_acplus.api_client import ApiClient
from moneyforward_acplus.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class JournalsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_journal_file(self, create_journal_file_request, **kwargs):  # noqa: E501
        """仕訳帳作成要求  # noqa: E501

        仕訳帳作成をリクエストします。仕訳帳はリクエスト受付後に非同期で作成されます。仕訳帳の作成状況の確認や作成結果の取得は受付成功時に返却される作成要求IDを指定して仕訳帳作成状況取得APIや仕訳帳ダウンロードAPIを呼び出します。開始日と終了日に含まれる会計期は1つである必要があります。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_journal_file(create_journal_file_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateJournalFileRequest create_journal_file_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateJournalFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_journal_file_with_http_info(create_journal_file_request, **kwargs)  # noqa: E501

    def create_journal_file_with_http_info(self, create_journal_file_request, **kwargs):  # noqa: E501
        """仕訳帳作成要求  # noqa: E501

        仕訳帳作成をリクエストします。仕訳帳はリクエスト受付後に非同期で作成されます。仕訳帳の作成状況の確認や作成結果の取得は受付成功時に返却される作成要求IDを指定して仕訳帳作成状況取得APIや仕訳帳ダウンロードAPIを呼び出します。開始日と終了日に含まれる会計期は1つである必要があります。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_journal_file_with_http_info(create_journal_file_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateJournalFileRequest create_journal_file_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateJournalFileResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_journal_file_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_journal_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_journal_file_request' is set
        if self.api_client.client_side_validation and ('create_journal_file_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_journal_file_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_journal_file_request` when calling `create_journal_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_journal_file_request' in local_var_params:
            body_params = local_var_params['create_journal_file_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/journals/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateJournalFileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_journal_file(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳削除  # noqa: E501

        作成済の仕訳帳を削除します。パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。作成要求IDで指定する仕訳帳が作成中の場合は失敗します。すでに削除済の仕訳帳に対して削除を実行した場合は成功します。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_journal_file(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_journal_file_with_http_info(request_id, **kwargs)  # noqa: E501

    def delete_journal_file_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳削除  # noqa: E501

        作成済の仕訳帳を削除します。パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。作成要求IDで指定する仕訳帳が作成中の場合は失敗します。すでに削除済の仕訳帳に対して削除を実行した場合は成功します。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_journal_file_with_http_info(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_journal_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'request_id' is set
        if self.api_client.client_side_validation and ('request_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['request_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_id` when calling `delete_journal_file`")  # noqa: E501

        if self.api_client.client_side_validation and 'request_id' in local_var_params and local_var_params['request_id'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `request_id` when calling `delete_journal_file`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'request_id' in local_var_params:
            path_params['requestId'] = local_var_params['request_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/journals/files/{requestId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_journal_file(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳ダウンロード  # noqa: E501

        仕訳帳をCSV形式でダウンロードできます。 パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。文字コードは仕訳帳作成要求APIでUTF8またはShiftJISから選択できます。デフォルトはUTF8となります。作成後90日以内の仕訳帳のみダウンロード可能です。 作成中または削除済の仕訳帳はダウンロードできません。   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_journal_file(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.download_journal_file_with_http_info(request_id, **kwargs)  # noqa: E501

    def download_journal_file_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳ダウンロード  # noqa: E501

        仕訳帳をCSV形式でダウンロードできます。 パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。文字コードは仕訳帳作成要求APIでUTF8またはShiftJISから選択できます。デフォルトはUTF8となります。作成後90日以内の仕訳帳のみダウンロード可能です。 作成中または削除済の仕訳帳はダウンロードできません。   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_journal_file_with_http_info(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_journal_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'request_id' is set
        if self.api_client.client_side_validation and ('request_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['request_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_id` when calling `download_journal_file`")  # noqa: E501

        if self.api_client.client_side_validation and 'request_id' in local_var_params and local_var_params['request_id'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `request_id` when calling `download_journal_file`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'request_id' in local_var_params:
            path_params['requestId'] = local_var_params['request_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/journals/files/{requestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_journal_file_status(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳作成状況取得  # noqa: E501

        仕訳帳作成状況を取得します。パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。作成後90日以内の仕訳帳のみ状況を取得可能です。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_journal_file_status(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JournalFileStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_journal_file_status_with_http_info(request_id, **kwargs)  # noqa: E501

    def get_journal_file_status_with_http_info(self, request_id, **kwargs):  # noqa: E501
        """仕訳帳作成状況取得  # noqa: E501

        仕訳帳作成状況を取得します。パラメータで指定する作成要求IDは仕訳帳作成要求APIで取得したものです。作成後90日以内の仕訳帳のみ状況を取得可能です。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_journal_file_status_with_http_info(request_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int request_id: 作成要求ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JournalFileStatus, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_journal_file_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'request_id' is set
        if self.api_client.client_side_validation and ('request_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['request_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_id` when calling `get_journal_file_status`")  # noqa: E501

        if self.api_client.client_side_validation and 'request_id' in local_var_params and local_var_params['request_id'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `request_id` when calling `get_journal_file_status`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'request_id' in local_var_params:
            path_params['requestId'] = local_var_params['request_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/journals/files/{requestId}/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JournalFileStatus',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_journal_file_status_list(self, **kwargs):  # noqa: E501
        """仕訳帳作成状況一覧取得  # noqa: E501

        仕訳帳作成状況の一覧を取得します。作成後90日以内の仕訳帳のみ状況を取得可能です。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_journal_file_status_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: 仕訳帳作成状況一覧の取得開始位置
        :param int limit: 仕訳帳作成状況一覧の取得件数
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[JournalFileStatus]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_journal_file_status_list_with_http_info(**kwargs)  # noqa: E501

    def get_journal_file_status_list_with_http_info(self, **kwargs):  # noqa: E501
        """仕訳帳作成状況一覧取得  # noqa: E501

        仕訳帳作成状況の一覧を取得します。作成後90日以内の仕訳帳のみ状況を取得可能です。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_journal_file_status_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: 仕訳帳作成状況一覧の取得開始位置
        :param int limit: 仕訳帳作成状況一覧の取得件数
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[JournalFileStatus], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_journal_file_status_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_journal_file_status_list`, must be a value greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 1000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_journal_file_status_list`, must be a value less than or equal to `1000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_journal_file_status_list`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/journals/files/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[JournalFileStatus]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from moneyforward_acplus.configuration import Configuration


class CreateJournalFileRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'from_date': 'date',
        'to_date': 'date',
        'approval_status': 'str',
        'character_set': 'str'
    }

    attribute_map = {
        'from_date': 'fromDate',
        'to_date': 'toDate',
        'approval_status': 'approvalStatus',
        'character_set': 'characterSet'
    }

    def __init__(self, from_date=None, to_date=None, approval_status='approved', character_set='utf8', local_vars_configuration=None):  # noqa: E501
        """CreateJournalFileRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._from_date = None
        self._to_date = None
        self._approval_status = None
        self._character_set = None
        self.discriminator = None

        self.from_date = from_date
        self.to_date = to_date
        if approval_status is not None:
            self.approval_status = approval_status
        if character_set is not None:
            self.character_set = character_set

    @property
    def from_date(self):
        """Gets the from_date of this CreateJournalFileRequest.  # noqa: E501

        開始日付  # noqa: E501

        :return: The from_date of this CreateJournalFileRequest.  # noqa: E501
        :rtype: date
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this CreateJournalFileRequest.

        開始日付  # noqa: E501

        :param from_date: The from_date of this CreateJournalFileRequest.  # noqa: E501
        :type: date
        """
        if self.local_vars_configuration.client_side_validation and from_date is None:  # noqa: E501
            raise ValueError("Invalid value for `from_date`, must not be `None`")  # noqa: E501

        self._from_date = from_date

    @property
    def to_date(self):
        """Gets the to_date of this CreateJournalFileRequest.  # noqa: E501

        終了日付  # noqa: E501

        :return: The to_date of this CreateJournalFileRequest.  # noqa: E501
        :rtype: date
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this CreateJournalFileRequest.

        終了日付  # noqa: E501

        :param to_date: The to_date of this CreateJournalFileRequest.  # noqa: E501
        :type: date
        """
        if self.local_vars_configuration.client_side_validation and to_date is None:  # noqa: E501
            raise ValueError("Invalid value for `to_date`, must not be `None`")  # noqa: E501

        self._to_date = to_date

    @property
    def approval_status(self):
        """Gets the approval_status of this CreateJournalFileRequest.  # noqa: E501

        承認ステータス  # noqa: E501

        :return: The approval_status of this CreateJournalFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this CreateJournalFileRequest.

        承認ステータス  # noqa: E501

        :param approval_status: The approval_status of this CreateJournalFileRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["approved", "unapproved", "both"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and approval_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `approval_status` ({0}), must be one of {1}"  # noqa: E501
                .format(approval_status, allowed_values)
            )

        self._approval_status = approval_status

    @property
    def character_set(self):
        """Gets the character_set of this CreateJournalFileRequest.  # noqa: E501

        文字コード  # noqa: E501

        :return: The character_set of this CreateJournalFileRequest.  # noqa: E501
        :rtype: str
        """
        return self._character_set

    @character_set.setter
    def character_set(self, character_set):
        """Sets the character_set of this CreateJournalFileRequest.

        文字コード  # noqa: E501

        :param character_set: The character_set of this CreateJournalFileRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["utf8", "sjis"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and character_set not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `character_set` ({0}), must be one of {1}"  # noqa: E501
                .format(character_set, allowed_values)
            )

        self._character_set = character_set

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateJournalFileRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateJournalFileRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import moneyforward_acplus
from moneyforward_acplus.models.create_journal_file_request import CreateJournalFileRequest  # noqa: E501
from moneyforward_acplus.rest import ApiException

class TestCreateJournalFileRequest(unittest.TestCase):
    """CreateJournalFileRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateJournalFileRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = moneyforward_acplus.models.create_journal_file_request.CreateJournalFileRequest()  # noqa: E501
        if include_optional :
            return CreateJournalFileRequest(
                from_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                to_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                approval_status = 'approved',
                character_set = 'utf8'
            )
        else :
            return CreateJournalFileRequest(
                from_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                to_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
        )

    def testCreateJournalFileRequest(self):
        """Test CreateJournalFileRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from moneyforward_acplus.api.accounts_api import AccountsApi
from moneyforward_acplus.api.journals_api import JournalsApi
from moneyforward_acplus.api.sub_accounts_api import SubAccountsApi

# import ApiClient
from moneyforward_acplus.api_client import ApiClient
from moneyforward_acplus.configuration import Configuration
from moneyforward_acplus.exceptions import OpenApiException
from moneyforward_acplus.exceptions import ApiTypeError
from moneyforward_acplus.exceptions import ApiValueError
from moneyforward_acplus.exceptions import ApiKeyError
from moneyforward_acplus.exceptions import ApiException
# import models into sdk package
from moneyforward_acplus.models.account import Account
from moneyforward_acplus.models.create_journal_file_request import CreateJournalFileRequest
from moneyforward_acplus.models.create_journal_file_response import CreateJournalFileResponse
from moneyforward_acplus.models.error import Error
from moneyforward_acplus.models.error_detail import ErrorDetail
from moneyforward_acplus.models.journal_file_status import JournalFileStatus
from moneyforward_acplus.models.sub_account import SubAccount




# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from moneyforward_acplus.configuration import Configuration


class Account(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_financial_statements_type': 'str',
        'category_name': 'str',
        'account_id': 'int',
        'account_name': 'str',
        'tax': 'str',
        'is_enabled': 'bool'
    }

    attribute_map = {
        'account_financial_statements_type': 'accountFinancialStatementsType',
        'category_name': 'categoryName',
        'account_id': 'accountId',
        'account_name': 'accountName',
        'tax': 'tax',
        'is_enabled': 'isEnabled'
    }

    def __init__(self, account_financial_statements_type=None, category_name=None, account_id=None, account_name=None, tax=None, is_enabled=None, local_vars_configuration=None):  # noqa: E501
        """Account - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_financial_statements_type = None
        self._category_name = None
        self._account_id = None
        self._account_name = None
        self._tax = None
        self._is_enabled = None
        self.discriminator = None

        self.account_financial_statements_type = account_financial_statements_type
        self.category_name = category_name
        self.account_id = account_id
        self.account_name = account_name
        self.tax = tax
        self.is_enabled = is_enabled

    @property
    def account_financial_statements_type(self):
        """Gets the account_financial_statements_type of this Account.  # noqa: E501

        帳票  # noqa: E501

        :return: The account_financial_statements_type of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_financial_statements_type

    @account_financial_statements_type.setter
    def account_financial_statements_type(self, account_financial_statements_type):
        """Sets the account_financial_statements_type of this Account.

        帳票  # noqa: E501

        :param account_financial_statements_type: The account_financial_statements_type of this Account.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_financial_statements_type is None:  # noqa: E501
            raise ValueError("Invalid value for `account_financial_statements_type`, must not be `None`")  # noqa: E501

        self._account_financial_statements_type = account_financial_statements_type

    @property
    def category_name(self):
        """Gets the category_name of this Account.  # noqa: E501

        分類  # noqa: E501

        :return: The category_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """Sets the category_name of this Account.

        分類  # noqa: E501

        :param category_name: The category_name of this Account.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and category_name is None:  # noqa: E501
            raise ValueError("Invalid value for `category_name`, must not be `None`")  # noqa: E501

        self._category_name = category_name

    @property
    def account_id(self):
        """Gets the account_id of this Account.  # noqa: E501

        勘定科目ID  # noqa: E501

        :return: The account_id of this Account.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Account.

        勘定科目ID  # noqa: E501

        :param account_id: The account_id of this Account.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def account_name(self):
        """Gets the account_name of this Account.  # noqa: E501

        勘定科目名  # noqa: E501

        :return: The account_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this Account.

        勘定科目名  # noqa: E501

        :param account_name: The account_name of this Account.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_name is None:  # noqa: E501
            raise ValueError("Invalid value for `account_name`, must not be `None`")  # noqa: E501

        self._account_name = account_name

    @property
    def tax(self):
        """Gets the tax of this Account.  # noqa: E501

        税区分  # noqa: E501

        :return: The tax of this Account.  # noqa: E501
        :rtype: str
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this Account.

        税区分  # noqa: E501

        :param tax: The tax of this Account.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tax is None:  # noqa: E501
            raise ValueError("Invalid value for `tax`, must not be `None`")  # noqa: E501

        self._tax = tax

    @property
    def is_enabled(self):
        """Gets the is_enabled of this Account.  # noqa: E501

        使用  # noqa: E501

        :return: The is_enabled of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this Account.

        使用  # noqa: E501

        :param is_enabled: The is_enabled of this Account.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `is_enabled`, must not be `None`")  # noqa: E501

        self._is_enabled = is_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Account):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import moneyforward_acplus
from moneyforward_acplus.models.sub_account import SubAccount  # noqa: E501
from moneyforward_acplus.rest import ApiException

class TestSubAccount(unittest.TestCase):
    """SubAccount unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubAccount
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = moneyforward_acplus.models.sub_account.SubAccount()  # noqa: E501
        if include_optional :
            return SubAccount(
                account_id = 56,
                sub_account_name = '0',
                tax = '0'
            )
        else :
            return SubAccount(
                account_id = 56,
                sub_account_name = '0',
                tax = '0',
        )

    def testSubAccount(self):
        """Test SubAccount"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from moneyforward_acplus.api.accounts_api import AccountsApi
from moneyforward_acplus.api.journals_api import JournalsApi
from moneyforward_acplus.api.sub_accounts_api import SubAccountsApi



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import moneyforward_acplus
from moneyforward_acplus.models.journal_file_status import JournalFileStatus  # noqa: E501
from moneyforward_acplus.rest import ApiException

class TestJournalFileStatus(unittest.TestCase):
    """JournalFileStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JournalFileStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = moneyforward_acplus.models.journal_file_status.JournalFileStatus()  # noqa: E501
        if include_optional :
            return JournalFileStatus(
                request_id = 0,
                requested_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                request_params = moneyforward_acplus.models.create_journal_file_request.CreateJournalFileRequest(
                    from_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                    to_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                    approval_status = 'approved',
                    character_set = 'utf8', ),
                status = 'pending',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else :
            return JournalFileStatus(
                request_id = 0,
                requested_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                request_params = moneyforward_acplus.models.create_journal_file_request.CreateJournalFileRequest(
                    from_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                    to_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                    approval_status = 'approved',
                    character_set = 'utf8', ),
                status = 'pending',
        )

    def testJournalFileStatus(self):
        """Test JournalFileStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from moneyforward_acplus.configuration import Configuration


class Error(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'title': 'str',
        'detail': 'str',
        'errors': 'list[ErrorDetail]'
    }

    attribute_map = {
        'type': 'type',
        'title': 'title',
        'detail': 'detail',
        'errors': 'errors'
    }

    def __init__(self, type='internal_error', title=None, detail=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """Error - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._title = None
        self._detail = None
        self._errors = None
        self.discriminator = None

        self.type = type
        self.title = title
        self.detail = detail
        if errors is not None:
            self.errors = errors

    @property
    def type(self):
        """Gets the type of this Error.  # noqa: E501

        エラー種別:   * `validation_failed`: リクエストボディやパラメータのバリデーションエラー   * `operation_not_completed`: 処理待ちや処理中のリクエストに対し、ファイルダウンロードや削除を要求した   * `invalid_credential`: 認証・認可情報が不正   * `permission_denied`: APIを実行する権限がない   * `request_not_found`: 指定された作成要求IDが存在しない   * `data_creation_failed`: 作成要求を受けたが、その後の処理でデータやファイル生成に失敗した   * `unsupported_media_type`: APIでサポートされていないリクエスト形式。Content-Type が不正な場合など。   * `internal_error`: 内部エラー   # noqa: E501

        :return: The type of this Error.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Error.

        エラー種別:   * `validation_failed`: リクエストボディやパラメータのバリデーションエラー   * `operation_not_completed`: 処理待ちや処理中のリクエストに対し、ファイルダウンロードや削除を要求した   * `invalid_credential`: 認証・認可情報が不正   * `permission_denied`: APIを実行する権限がない   * `request_not_found`: 指定された作成要求IDが存在しない   * `data_creation_failed`: 作成要求を受けたが、その後の処理でデータやファイル生成に失敗した   * `unsupported_media_type`: APIでサポートされていないリクエスト形式。Content-Type が不正な場合など。   * `internal_error`: 内部エラー   # noqa: E501

        :param type: The type of this Error.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["validation_failed", "operation_not_completed", "invalid_credential", "permission_denied", "request_not_found", "data_creation_failed", "unsupported_media_type", "internal_error"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def title(self):
        """Gets the title of this Error.  # noqa: E501

        エラー概要  # noqa: E501

        :return: The title of this Error.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Error.

        エラー概要  # noqa: E501

        :param title: The title of this Error.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def detail(self):
        """Gets the detail of this Error.  # noqa: E501

        エラーの詳細な説明  # noqa: E501

        :return: The detail of this Error.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this Error.

        エラーの詳細な説明  # noqa: E501

        :param detail: The detail of this Error.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and detail is None:  # noqa: E501
            raise ValueError("Invalid value for `detail`, must not be `None`")  # noqa: E501

        self._detail = detail

    @property
    def errors(self):
        """Gets the errors of this Error.  # noqa: E501

        エラー詳細のリスト  # noqa: E501

        :return: The errors of this Error.  # noqa: E501
        :rtype: list[ErrorDetail]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this Error.

        エラー詳細のリスト  # noqa: E501

        :param errors: The errors of this Error.  # noqa: E501
        :type: list[ErrorDetail]
        """

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Error):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.1
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "moneyforward-acplus"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="マネーフォワードクラウド会計Plus API",
    author="OTA2000",
    author_email="yasuhiroota26@gmail.com",
    url="https://github.com/moneyforward-api-client/acplus-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "マネーフォワードクラウド会計Plus API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    マネーフォワードクラウド会計PlusのAPI
    """
)



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import moneyforward_acplus
from moneyforward_acplus.api.journals_api import JournalsApi  # noqa: E501
from moneyforward_acplus.rest import ApiException


class TestJournalsApi(unittest.TestCase):
    """JournalsApi unit test stubs"""

    def setUp(self):
        self.api = moneyforward_acplus.api.journals_api.JournalsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_journal_file(self):
        """Test case for create_journal_file

        仕訳帳作成要求  # noqa: E501
        """
        pass

    def test_delete_journal_file(self):
        """Test case for delete_journal_file

        仕訳帳削除  # noqa: E501
        """
        pass

    def test_download_journal_file(self):
        """Test case for download_journal_file

        仕訳帳ダウンロード  # noqa: E501
        """
        pass

    def test_get_journal_file_status(self):
        """Test case for get_journal_file_status

        仕訳帳作成状況取得  # noqa: E501
        """
        pass

    def test_get_journal_file_status_list(self):
        """Test case for get_journal_file_status_list

        仕訳帳作成状況一覧取得  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    マネーフォワードクラウド会計Plus API

    マネーフォワードクラウド会計PlusのAPI  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: yasuhiroota26@gmail.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from moneyforward_acplus.configuration import Configuration


class JournalFileStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'request_id': 'int',
        'requested_at': 'datetime',
        'request_params': 'CreateJournalFileRequest',
        'status': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'request_id': 'requestId',
        'requested_at': 'requestedAt',
        'request_params': 'requestParams',
        'status': 'status',
        'created_at': 'createdAt'
    }

    def __init__(self, request_id=None, requested_at=None, request_params=None, status=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """JournalFileStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._request_id = None
        self._requested_at = None
        self._request_params = None
        self._status = None
        self._created_at = None
        self.discriminator = None

        self.request_id = request_id
        self.requested_at = requested_at
        self.request_params = request_params
        self.status = status
        if created_at is not None:
            self.created_at = created_at

    @property
    def request_id(self):
        """Gets the request_id of this JournalFileStatus.  # noqa: E501

        作成要求ID  # noqa: E501

        :return: The request_id of this JournalFileStatus.  # noqa: E501
        :rtype: int
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this JournalFileStatus.

        作成要求ID  # noqa: E501

        :param request_id: The request_id of this JournalFileStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and request_id is None:  # noqa: E501
            raise ValueError("Invalid value for `request_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                request_id is not None and request_id < 0):  # noqa: E501
            raise ValueError("Invalid value for `request_id`, must be a value greater than or equal to `0`")  # noqa: E501

        self._request_id = request_id

    @property
    def requested_at(self):
        """Gets the requested_at of this JournalFileStatus.  # noqa: E501

        作成要求日時  # noqa: E501

        :return: The requested_at of this JournalFileStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this JournalFileStatus.

        作成要求日時  # noqa: E501

        :param requested_at: The requested_at of this JournalFileStatus.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and requested_at is None:  # noqa: E501
            raise ValueError("Invalid value for `requested_at`, must not be `None`")  # noqa: E501

        self._requested_at = requested_at

    @property
    def request_params(self):
        """Gets the request_params of this JournalFileStatus.  # noqa: E501


        :return: The request_params of this JournalFileStatus.  # noqa: E501
        :rtype: CreateJournalFileRequest
        """
        return self._request_params

    @request_params.setter
    def request_params(self, request_params):
        """Sets the request_params of this JournalFileStatus.


        :param request_params: The request_params of this JournalFileStatus.  # noqa: E501
        :type: CreateJournalFileRequest
        """
        if self.local_vars_configuration.client_side_validation and request_params is None:  # noqa: E501
            raise ValueError("Invalid value for `request_params`, must not be `None`")  # noqa: E501

        self._request_params = request_params

    @property
    def status(self):
        """Gets the status of this JournalFileStatus.  # noqa: E501

        作成状況  # noqa: E501

        :return: The status of this JournalFileStatus.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JournalFileStatus.

        作成状況  # noqa: E501

        :param status: The status of this JournalFileStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["pending", "in_progress", "created", "failed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this JournalFileStatus.  # noqa: E501

        作成日時  # noqa: E501

        :return: The created_at of this JournalFileStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this JournalFileStatus.

        作成日時  # noqa: E501

        :param created_at: The created_at of this JournalFileStatus.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JournalFileStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JournalFileStatus):
            return True

        return self.to_dict() != other.to_dict()
